@@ -5,7 +5,7 @@ package SSH::Batch;
 use strict;
 use warnings;
 
-our $VERSION = '0.029';
+our $VERSION = '0.030';
 
 1;
 __END__
@@ -18,7 +18,7 @@ SSH::Batch - Cluster operations based on parallel SSH, set and interval arithmet
 
 =head1 VERSION
 
-This document describes SSH::Batch 0.029 released on 29 April 2012.
+This document describes SSH::Batch 0.030 released on 8 November 2015.
 
 =head1 SYNOPSIS
 
@@ -64,9 +64,12 @@ Run command on clusters. (atnodes calls fornodes internally.)
     # use -w to prompt for password if w/o SSH key (no echo back)
     $ atnodes hostname '{ps}' -u agentz -w
 
-    # or prompt for password if sudo required...
+    # or prompt for password if both login and sudo are required...
     $ atnodes 'sudo apachectl restart' '{ps}' -w
 
+    # or prompt for password for sudo only...
+    $ atnodes 'sudo apachectl restart' '{ps}' -W
+
     # run sudo command if tty required...
     $ atnodes -tty 'sudo apachectl restart' '{ps}'
 
@@ -394,9 +397,7 @@ Liseen Wan (万珣新) C<< <liseen.wan@gmail.com> >>
 
 This module as well as its programs are licensed under the BSD License.
 
-Copyright (c) 2009, Yahoo! China EEEE Works, Alibaba Inc. All rights reserved.
-
-Copyright (C) 2009, 2010, 2011, Zhang "agentzh" Yichun (章亦春). All rights reserved.
+Copyright (C) 2009-2015, Yichun "agentzh" Zhang (章亦春). All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
